@@ -26,7 +26,7 @@ class FileHandlers:
             path = Path(os.getenv("LOCALAPPDATA")) / path
             op_sys = "nt"
         else:
-            path = Path(os.path.abspath(os.getenv('HOME'))) / '.domains-api'
+            path = Path(os.path.abspath(os.getenv("HOME"))) / ".domains-api"
             op_sys = "pos"
         return path, op_sys
 
@@ -103,8 +103,17 @@ class FileHandlers:
 
     def delete_user(self):
         """Delete user pickle file (serialized user instance)."""
-        if input("Are you sure you want to delete the current user? [Y/n] ").lower() != "n":
-            os.remove(self.user_file)
+        if (
+            input("Are you sure you want to delete the current user? [Y/n] ").lower()
+            == "n"
+        ):
+            return
+        os.remove(self.user_file)
+        self.log("User deleted", "info")
+        print(
+            "Run the script without options to create a new user, or "
+            '"domains-api -l path/to/pickle" to load one from file'
+        )
 
     def clear_logs(self):
         with open(self.log_file, "r") as r:
